@@ -47,16 +47,22 @@ def create_project(file, project_name, filename, comp_name, includes, defines,
     file.write('create_clock -period {} -name default\n'.format(
         period
     ))
+    # Register function inputs and output to get accurate timings
+
     file.write('set_clock_uncertainty 0.0 default\n')
     ctrl_mode = 'ap_ctrl_hs' if ctrl_hs else 'ap_ctrl_none'
     file.write(f'set_directive_interface -mode {ctrl_mode} [get_top]\n')
     file.write('config_schedule -relax_ii_for_timing=0 -effort high\n')
     file.write('set_directive_inline -recursive [get_top]\n')
-    if pipeline and (depth_constraint is None or depth_constraint > 1):
+    reg_type = "off"
+    if pipeline:
         file.write('set_directive_pipeline -II 1 [get_top]\n')
     if depth_constraint is not None:
+        if depth_constraint == 1:
+            reg_type = 'scalar_all'
+            depth_constraint = 2
         file.write('set_directive_latency -min {} -max {} [get_top]\n'.format(depth_constraint, depth_constraint))
-
+    file.write(f'config_interface -register_io {reg_type}\n')
 
 def csynth_solution_script(file):
     """Generate a script in file for synthetizing solution solution_name of project project_name"""
